// this function verifies disk space in kilobytes
function verifyDiskSpace(dirPath, spaceRequired)
{
  var spaceAvailable;

  // Get the available disk space on the given path
  spaceAvailable = fileGetDiskSpaceAvailable(dirPath);

  // Convert the available disk space into kilobytes
  spaceAvailable = parseInt(spaceAvailable / 1024);

  // do the verification
  if(spaceAvailable < spaceRequired)
  {
    logComment("Insufficient disk space: " + dirPath);
    logComment("  required : " + spaceRequired + " K");
    logComment("  available: " + spaceAvailable + " K");
    return(false);
  }

  return(true);
}

// this function deletes a file if it exists
function deleteThisFile(dirKey, file)
{
  var fFileToDelete;

  fFileToDelete = getFolder(dirKey, file);
  logComment(file + " file: " + fFileToDelete);
  if(File.exists(fFileToDelete))
  {
    fileDelete(fFileToDelete);
    return(true);
  }
  else
    return(false);
}

// this function deletes a folder (recursively) if it exists
function deleteThisFolder(dirKey, folder)
{
  var fToDelete;

  fToDelete = getFolder(dirKey, folder);
  logComment(folder + " folder: " + fToDelete);
  if(File.exists(fToDelete))
  {
    File.dirRemove(fToDelete, true);
    return(true);
  }
  else
    return(false);
}

// OS type detection
// which platform?
function getPlatform()
{
  var platformStr;
  var platformNode;

  if('platform' in Install)
  {
    platformStr = new String(Install.platform);

    if (!platformStr.search(/^Macintosh/))
      platformNode = 'mac';
    else if (!platformStr.search(/^Win/))
      platformNode = 'win';
    else
      platformNode = 'unix';
  }
  else
  {
    var fOSMac  = getFolder("Mac System");
    var fOSWin  = getFolder("Win System");

    logComment("fOSMac: "  + fOSMac);
    logComment("fOSWin: "  + fOSWin);

    if(fOSMac != null)
      platformNode = 'mac';
    else if(fOSWin != null)
      platformNode = 'win';
    else
      platformNode = 'unix';
  }

  return platformNode;
}


var srDest = 480;

var err;
var fProgram;
var platformNode;

platformNode = getPlatform();
logComment("initInstall: platformNode=" + platformNode);
// end
// end - OS type detection

// --- LOCALIZATION NOTE: translate only these ---
var prettyName = "English (US) Language Pack";
var langcode = "en";
var chromeNode = langcode + "-US";
// --- END LOCALIZABLE RESOURCES ---
var regName      = "locales/mozilla/" + chromeNode;
var chromeName   = chromeNode + ".jar";
var platformName = langcode + "-" + platformNode + ".jar";
var localeName   = "locale/" + chromeNode + "/";

err = initInstall(prettyName, regName, "5.0.0.2001091311"); 
logComment("initInstall: " + err);

fProgram = getFolder("Program");
logComment("fProgram: " + fProgram);

if (verifyDiskSpace(fProgram, srDest))
{
    err = addDirectory("",
                   "5.0.0.2001091311",
                   "viewer",
                   fProgram,
                   "",
                   true);
    logComment("addDirectory() returned: " + err);

    var cf = getFolder("Chrome");
    registerChrome(LOCALE, getFolder(cf, chromeName), localeName + "global/");
    registerChrome(LOCALE, getFolder(cf, chromeName), localeName + "communicator/");
    registerChrome(LOCALE, getFolder(cf, chromeName), localeName + "messenger/");
    registerChrome(LOCALE, getFolder(cf, chromeName), localeName + "editor/");
    registerChrome(LOCALE, getFolder(cf, chromeName), localeName + "navigator/");
    registerChrome(LOCALE, getFolder(cf, chromeName), localeName + "necko/");
    registerChrome(LOCALE, getFolder(cf, chromeName), localeName + "cookie/");
    registerChrome(LOCALE, getFolder(cf, chromeName), localeName + "wallet/");
    registerChrome(LOCALE, getFolder(cf, chromeName), localeName + "content-packs/");
    registerChrome(LOCALE, getFolder(cf, chromeName), localeName + "help/");
    registerChrome(LOCALE, getFolder(cf, chromeName), localeName + "pippki/");
    registerChrome(LOCALE, getFolder(cf, chromeName), localeName + "pipnss/");

    registerChrome(LOCALE, getFolder(cf, platformName), localeName + "global-platform/");
    registerChrome(LOCALE, getFolder(cf, platformName), localeName + "communicator-platform/");

    if(err == SUCCESS)
    {
        err = performInstall(); 
        logComment("performInstall() returned: " + err);
    }
    else
    {
        cancelInstall(err);
        logComment("cancelInstall due to error: " + err);
    }
}
else
    cancelInstall(INSUFFICIENT_DISK_SPACE);
